@@ -179,7 +179,7 @@ func jsRelease(ctx string, token byte) {
 	if JSW == nil {
 		return
 	}
-	tracef(CJS, "release from %s", ctx)
+	tracef(CJS, "release from: %s", ctx)
 	jsTokensM.Lock()
 	jsTokens[token]--
 	jsReleaseNoLock(token)
@@ -200,7 +200,7 @@ func jsAcquire(ctx string) byte {
 	if JSR == nil {
 		return BMakeGoodToken
 	}
-	tracef(CJS, "acquire for %s", ctx)
+	tracef(CJS, "acquire for: %s", ctx)
 	token := []byte{0}
 	if n, err := JSR.Read(token); err != nil || n != 1 {
 		log.Fatalln("can not read JSR:", err)
@@ -208,6 +208,6 @@ func jsAcquire(ctx string) byte {
 	jsTokensM.Lock()
 	jsTokens[token[0]]++
 	jsTokensM.Unlock()
-	tracef(CJS, "acquired for %s", ctx)
+	tracef(CJS, "acquired for: %s", ctx)
 	return token[0]
 }
