@@ -70,6 +70,7 @@ var (
 	StderrPrefix string
 	StopIfMod    = false
 	Jobs         sync.WaitGroup
+	TmpsToClean  = make(map[string]struct{})
 
 	flagTrace          *bool
 	flagTraceAll       *bool
@@ -291,7 +292,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 			return fmt.Errorf("%s externally modified", tgt)
 		}
 		Jobs.Add(1)
-		tracef(CWarn, "%s externally modified: not redoing", tgt)
+		tracef(CWarn, "%s: externally modified: not redoing", tgt)
 		go func() {
 			errs <- nil
 			Jobs.Done()
@@ -304,7 +305,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 			return fmt.Errorf("%s already existing", tgt)
 		}
 		Jobs.Add(1)
-		tracef(CWarn, "%s already existing: not redoing", tgt)
+		tracef(CWarn, "%s: already existing: not redoing", tgt)
 		go func() {
 			errs <- nil
 			Jobs.Done()
@@ -319,6 +320,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 		lockRelease()
 		return TgtError{tgt, ErrLine(err)}
 	}
+	TmpsToClean[fdDep.Name()] = struct{}{}
 	fdDepOpened := true
 	fdDepExists := true
 	fdDepW := bufio.NewWriter(fdDep)
@@ -328,6 +330,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 			fdDep.Close()
 		}
 		if fdDepExists {
+			delete(TmpsToClean, fdDep.Name())
 			os.Remove(fdDep.Name())
 		}
 	}
@@ -407,6 +410,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 		cleanup()
 		return TgtError{tgt, ErrLine(err)}
 	}
+	TmpsToClean[fdStdout.Name()] = struct{}{}
 	fdStdout.Close()
 	tmpPath := fdStdout.Name() + ".3" // and for $3
 	tmpPathRel := mustRel(cwd, tmpPath)
@@ -607,9 +611,12 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 			}
 			lockRelease()
 			if fdDepExists {
+				delete(TmpsToClean, fdDep.Name())
 				os.Remove(fdDep.Name())
 			}
+			delete(TmpsToClean, fdStdout.Name())
 			os.Remove(fdStdout.Name())
+			delete(TmpsToClean, tmpPath)
 			os.Remove(tmpPath)
 			if FdStatus != nil {
 				if _, err = FdStatus.Write([]byte{StatusDone}); err != nil {
@@ -635,7 +642,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 		RunningProcs[cmd.Process.Pid] = cmd.Process
 		RunningProcsM.Unlock()
 		pid := fmt.Sprintf("[%d]", cmd.Process.Pid)
-		tracef(CDebug, "%s runs %s", tgt, pid)
+		tracef(CDebug, "%s: runs %s", tgt, pid)
 
 		stderrTerm := make(chan struct{})
 		go func() {
@@ -745,6 +752,9 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 
 		// Do we need to ifcreate it, or ifchange with renaming?
 		if fd == nil {
+			if Level > 0 {
+				tracef(CWarn, "%s: nothing written to target", tgt)
+			}
 			os.Remove(tgt.a)
 			err = ifcreate(fdDepW, fdDep.Name(), tgtT)
 			if err != nil {
@@ -765,7 +775,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 					goto Finish
 				}
 				if hsh == hshPrev {
-					tracef(CDebug, "%s has same hash, not renaming", tgt)
+					tracef(CDebug, "%s: has same hash, not renaming", tgt)
 					err = ErrLine(os.Remove(fd.Name()))
 					if err != nil {
 						goto Finish
@@ -831,6 +841,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 		if err != nil {
 			goto Finish
 		}
+		delete(TmpsToClean, fdDep.Name())
 		fdDepExists = false
 		if !NoSync {
 			err = ErrLine(syncDir(redoDir))
@@ -850,7 +861,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 			}
 			for _, ifcreate := range dep.ifcreates {
 				if _, exists := ifchangeSeen[ifcreate.a]; exists {
-					tracef(CWarn, "simultaneous ifcreate and ifchange records: %s", tgt)
+					tracef(CWarn, "%s: simultaneous ifcreate and ifchange records", tgt)
 				}
 			}
 		} else if errors.Is(err, fs.ErrNotExist) {
